@@ -1,5 +1,5 @@
 # Copyright 2020 Josh Wills. All rights reserved.
-# Copyright Materialize, Inc. All rights reserved.
+# Copyright Materialize, Inc. and contributors. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,11 +14,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from dbt.adapters.materialize.connections import MaterializeConnectionManager
-from dbt.adapters.materialize.connections import MaterializeCredentials
-from dbt.adapters.materialize.impl import MaterializeAdapter
-
 from dbt.adapters.base import AdapterPlugin
+from dbt.adapters.materialize.connections import (
+    MaterializeConnectionManager,
+    MaterializeCredentials,
+)
+from dbt.adapters.materialize.impl import MaterializeAdapter
 from dbt.include import materialize
 
 Plugin = AdapterPlugin(
