@@ -25,7 +25,7 @@
 
   {{ run_hooks(pre_hooks, inside_transaction=False) }}
 
-  {% call statement('main', auto_begin=False) -%}
+  {% call statement('main') -%}
     -- Creates a materialized view, not a table, in Materialize
     {{ materialize__create_materialized_view_as(target_relation, sql) }}
   {%- endcall %}
